# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/datastore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!admin/v1/types/v1/datastore.proto\x12\x11\x61\x64min.v1.types.v1\"\xb3\x04\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\ncreated_at\x18\x02 \x01(\x03R\tcreatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12+\n\x11original_hostname\x18\x05 \x01(\tR\x10originalHostname\x12\x12\n\x04port\x18\x06 \x01(\x05R\x04port\x12\x1e\n\ntechnology\x18\x07 \x01(\tR\ntechnology\x12/\n\x14health_check_db_name\x18\x08 \x01(\tR\x11healthCheckDbName\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\t \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\n \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x0b \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12\x1f\n\x08username\x18\x0c \x01(\tH\x00R\x08username\x88\x01\x01\x12\x1f\n\x08password\x18\r \x01(\tH\x01R\x08password\x88\x01\x01\x12 \n\x0b\x65nvironment\x18\x0e \x01(\tR\x0b\x65nvironmentB\x0b\n\t_usernameB\x0b\n\t_passwordB\xe1\x01\n\x15\x63om.admin.v1.types.v1B\x0e\x44\x61tastoreProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.datastore_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\016DatastoreProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_DATASTORE']._serialized_start=57
  _globals['_DATASTORE']._serialized_end=620
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Satellite(_message.Message):
    __slots__ = ["id", "name", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    status: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import inventory_pb2 as admin_dot_v1_dot_inventory__pb2


class InventoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInventoryHierarchical = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryHierarchical',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.FromString,
                )
        self.GetInventory = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventory',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.FromString,
                )
        self.GetInventoryFlat = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryFlat',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.FromString,
                )
        self.GetInventoryFlatOld = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryFlatOld',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.FromString,
                )
        self.GetInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.FromString,
                )
        self.UpdateColumnLockStatus = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnLockStatus',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.FromString,
                )
        self.UpdateColumnDataLabel = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnDataLabel',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.FromString,
                )
        self.UpdateColumnFieldEncryption = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnFieldEncryption',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.FromString,
                )
        self.UpdateInventoryObjectTags = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateInventoryObjectTags',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.FromString,
                )
        self.CreateInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/CreateInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.FromString,
                )
        self.DeleteInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.FromString,
                )
        self.CreateInventoryTag = channel.unary_unary(
                '/admin.v1.InventoryService/CreateInventoryTag',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.FromString,
                )
        self.GetInventoryTags = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryTags',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.FromString,
                )
        self.DeleteInventoryTag = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteInventoryTag',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.FromString,
                )
        self.GetInventoryMetrics = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryMetrics',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.FromString,
                )
        self.CreateDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/CreateDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.FromString,
                )
        self.GetDataDomains = channel.unary_unary(
                '/admin.v1.InventoryService/GetDataDomains',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.FromString,
                )
        self.GetDataDomainById = channel.unary_unary(
                '/admin.v1.InventoryService/GetDataDomainById',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.FromString,
                )
        self.UpdateDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.FromString,
                )
        self.DeleteDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.FromString,
                )


class InventoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetInventoryHierarchical(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryFlat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryFlatOld(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnLockStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnDataLabel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnFieldEncryption(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInventoryObjectTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInventoryTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInventoryTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataDomainById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InventoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInventoryHierarchical': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryHierarchical,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.SerializeToString,
            ),
            'GetInventory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventory,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.SerializeToString,
            ),
            'GetInventoryFlat': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryFlat,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.SerializeToString,
            ),
            'GetInventoryFlatOld': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryFlatOld,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.SerializeToString,
            ),
            'GetInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.SerializeToString,
            ),
            'UpdateColumnLockStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnLockStatus,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.SerializeToString,
            ),
            'UpdateColumnDataLabel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnDataLabel,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.SerializeToString,
            ),
            'UpdateColumnFieldEncryption': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnFieldEncryption,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.SerializeToString,
            ),
            'UpdateInventoryObjectTags': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInventoryObjectTags,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.SerializeToString,
            ),
            'CreateInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.SerializeToString,
            ),
            'DeleteInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.SerializeToString,
            ),
            'CreateInventoryTag': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInventoryTag,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.SerializeToString,
            ),
            'GetInventoryTags': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryTags,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.SerializeToString,
            ),
            'DeleteInventoryTag': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInventoryTag,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.SerializeToString,
            ),
            'GetInventoryMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryMetrics,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.SerializeToString,
            ),
            'CreateDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.SerializeToString,
            ),
            'GetDataDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataDomains,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.SerializeToString,
            ),
            'GetDataDomainById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataDomainById,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.SerializeToString,
            ),
            'UpdateDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.SerializeToString,
            ),
            'DeleteDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.InventoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InventoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetInventoryHierarchical(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryHierarchical',
            admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventory',
            admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryFlat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryFlat',
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryFlatOld(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryFlatOld',
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryObject',
            admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnLockStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnLockStatus',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnDataLabel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnDataLabel',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnFieldEncryption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnFieldEncryption',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInventoryObjectTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateInventoryObjectTags',
            admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateInventoryObject',
            admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteInventoryObject',
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInventoryTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateInventoryTag',
            admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryTags',
            admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInventoryTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteInventoryTag',
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryMetrics',
            admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateDataDomain',
            admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetDataDomains',
            admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataDomainById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetDataDomainById',
            admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateDataDomain',
            admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteDataDomain',
            admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61\x64min/v1/types/v1/group.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaa\x02\n\x05Group\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x16\n\x06status\x18\x05 \x01(\tR\x06status\x12/\n\x05roles\x18\x06 \x03(\x0b\x32\x19.admin.v1.types.v1.DbUserR\x05roles\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x19\n\x08user_ids\x18\x08 \x03(\tR\x07userIds\x12$\n\x0e\x64sync_group_id\x18\t \x01(\tR\x0c\x64syncGroupId\"\xfc\x01\n\x06\x44\x62User\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x64\x62_username\x18\x02 \x01(\tR\ndbUsername\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\x12\x1b\n\texpire_at\x18\x06 \x01(\x03R\x08\x65xpireAt\x12\x1d\n\ncreated_at\x18\x07 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x08 \x01(\x03R\tupdatedAt\x12\"\n\rdsync_user_id\x18\t \x01(\tR\x0b\x64syncUserIdB\xdd\x01\n\x15\x63om.admin.v1.types.v1B\nGroupProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\nGroupProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_GROUP']._serialized_start=86
  _globals['_GROUP']._serialized_end=384
  _globals['_DBUSER']._serialized_start=387
  _globals['_DBUSER']._serialized_end=639
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_log_pb2 import (
	CreateIntegrationLogsRequest,
	CreateIntegrationLogsResponse,
	GetIntegrationLogsRequest,
	GetIntegrationLogsResponse,
	GetIntegrationLogByIdRequest,
	GetIntegrationLogByIdResponse,
	DeleteIntegrationLogsRequest,
	DeleteIntegrationLogsResponse,
	CreateLogsLinkItemRequest,
	CreateLogsLinkItemResponse,
	GetLogsLinkItemByIdRequest,
	GetLogsLinkItemByIdResponse,
	DeleteLogsLinkItemRequest,
	DeleteLogsLinkItemResponse,
)

from .gen.admin.v1.integration_log_pb2_grpc import LogsServiceStub
class LogsService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = LogsServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateIntegrationLogs(self, request: CreateIntegrationLogsRequest) -> CreateIntegrationLogsResponse:
		return self.stub.CreateIntegrationLogs(request, metadata=self.headers)

	def GetIntegrationLogs(self, request: GetIntegrationLogsRequest) -> GetIntegrationLogsResponse:
		return self.stub.GetIntegrationLogs(request, metadata=self.headers)

	def GetIntegrationLogById(self, request: GetIntegrationLogByIdRequest) -> GetIntegrationLogByIdResponse:
		return self.stub.GetIntegrationLogById(request, metadata=self.headers)

	def DeleteIntegrationLogs(self, request: DeleteIntegrationLogsRequest) -> DeleteIntegrationLogsResponse:
		return self.stub.DeleteIntegrationLogs(request, metadata=self.headers)

	def CreateLogsLinkItem(self, request: CreateLogsLinkItemRequest) -> CreateLogsLinkItemResponse:
		return self.stub.CreateLogsLinkItem(request, metadata=self.headers)

	def GetLogsLinkItemById(self, request: GetLogsLinkItemByIdRequest) -> GetLogsLinkItemByIdResponse:
		return self.stub.GetLogsLinkItemById(request, metadata=self.headers)

	def DeleteLogsLinkItem(self, request: DeleteLogsLinkItemRequest) -> DeleteLogsLinkItemResponse:
		return self.stub.DeleteLogsLinkItem(request, metadata=self.headers)




from .types.v1 import datahub_pb2 as _datahub_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDatahubIntegrationRequest(_message.Message):
    __slots__ = ["sync_direction", "generalized_metadata_service_url", "active", "api_key", "synced_entities"]
    SYNC_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    GENERALIZED_METADATA_SERVICE_URL_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    SYNCED_ENTITIES_FIELD_NUMBER: _ClassVar[int]
    sync_direction: str
    generalized_metadata_service_url: str
    active: bool
    api_key: str
    synced_entities: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, sync_direction: _Optional[str] = ..., generalized_metadata_service_url: _Optional[str] = ..., active: bool = ..., api_key: _Optional[str] = ..., synced_entities: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateDatahubIntegrationResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatahubIntegrationRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatahubIntegrationResponse(_message.Message):
    __slots__ = ["integration"]
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _datahub_pb2.Datahub
    def __init__(self, integration: _Optional[_Union[_datahub_pb2.Datahub, _Mapping]] = ...) -> None: ...

class UpdateDatahubIntegrationRequest(_message.Message):
    __slots__ = ["id", "sync_direction", "generalized_metadata_service_url", "active", "api_key", "synced_entities"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SYNC_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    GENERALIZED_METADATA_SERVICE_URL_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    SYNCED_ENTITIES_FIELD_NUMBER: _ClassVar[int]
    id: str
    sync_direction: str
    generalized_metadata_service_url: str
    active: bool
    api_key: str
    synced_entities: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., sync_direction: _Optional[str] = ..., generalized_metadata_service_url: _Optional[str] = ..., active: bool = ..., api_key: _Optional[str] = ..., synced_entities: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateDatahubIntegrationResponse(_message.Message):
    __slots__ = ["integration"]
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _datahub_pb2.Datahub
    def __init__(self, integration: _Optional[_Union[_datahub_pb2.Datahub, _Mapping]] = ...) -> None: ...

class RefreshWebhookTokenRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class RefreshWebhookTokenResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class DeleteDatahubIntegrationRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDatahubIntegrationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OnlineInstance(_message.Message):
    __slots__ = ["instance_id", "last_seen", "start_time", "version"]
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    instance_id: str
    last_seen: _timestamp_pb2.Timestamp
    start_time: _timestamp_pb2.Timestamp
    version: str
    def __init__(self, instance_id: _Optional[str] = ..., last_seen: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., version: _Optional[str] = ...) -> None: ...

class OnlineSidecar(_message.Message):
    __slots__ = ["sidecar_id", "instances"]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    sidecar_id: str
    instances: _containers.RepeatedCompositeFieldContainer[OnlineInstance]
    def __init__(self, sidecar_id: _Optional[str] = ..., instances: _Optional[_Iterable[_Union[OnlineInstance, _Mapping]]] = ...) -> None: ...

class GetOnlineInstancesByOrgIdRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetOnlineInstancesByOrgIdResponse(_message.Message):
    __slots__ = ["sidecars"]
    class SidecarsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: OnlineSidecar
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[OnlineSidecar, _Mapping]] = ...) -> None: ...
    SIDECARS_FIELD_NUMBER: _ClassVar[int]
    sidecars: _containers.MessageMap[str, OnlineSidecar]
    def __init__(self, sidecars: _Optional[_Mapping[str, OnlineSidecar]] = ...) -> None: ...

class GetOnlineInstancesBySidecarIdRequest(_message.Message):
    __slots__ = ["sidecar_id"]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    sidecar_id: str
    def __init__(self, sidecar_id: _Optional[str] = ...) -> None: ...

class GetOnlineInstancesBySidecarIdResponse(_message.Message):
    __slots__ = ["instances"]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    instances: _containers.RepeatedCompositeFieldContainer[OnlineInstance]
    def __init__(self, instances: _Optional[_Iterable[_Union[OnlineInstance, _Mapping]]] = ...) -> None: ...



import grpc


from .gen.admin.v1.identities_pb2 import (
	ListGroupsRequest,
	CreateGroupRequest,
	GetGroupByIdRequest,
	DeleteGroupRequest,
	UpdateGroupRequest,
	LinkUsersToGroupRequest,
	LinkUsersToGroupV2Request,
	UnlinkUsersFromGroupRequest,
	CreateGroupResponse,
	GetGroupByIdResponse,
	DeleteGroupResponse,
	UpdateGroupResponse,
	ListGroupsResponse,
	LinkUsersToGroupResponse,
	LinkUsersToGroupV2Response,
	UnlinkUsersFromGroupResponse,
	UserLinkGroupResponse,
	ListUsersRequest,
	ListUsersResponse,
	CreateUserRequest,
	CreateUserResponse,
	CreateUserV2Request,
	CreateUserV2Response,
	GetUserByIdRequest,
	GetUserByIdResponse,
	DeleteUserRequest,
	DeleteUserResponse,
	UpdateUserRequest,
	UpdateUserResponse,
	GetMachineUserAuthTokenRequest,
	GetMachineUserAuthTokenResponse,
	RefreshMachineUserAuthTokenRequest,
	RefreshMachineUserAuthTokenResponse,
	GetUserExternalIdsRequest,
	GetUserExternalIdsResponse,
	MapUserToExternalIdRequest,
	MapUserToExternalIdResponse,
	DeleteExternalIdMappingRequest,
	DeleteExternalIdMappingResponse,
)

from .gen.admin.v1.identities_pb2_grpc import UserServiceStub
class UserService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = UserServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def ListUsers(self, request: ListUsersRequest) -> ListUsersResponse:
		return self.stub.ListUsers(request, metadata=self.headers)

	def CreateUser(self, request: CreateUserRequest) -> CreateUserResponse:
		return self.stub.CreateUser(request, metadata=self.headers)

	def CreateUserV2(self, request: CreateUserV2Request) -> CreateUserV2Response:
		return self.stub.CreateUserV2(request, metadata=self.headers)

	def GetUserById(self, request: GetUserByIdRequest) -> GetUserByIdResponse:
		return self.stub.GetUserById(request, metadata=self.headers)

	def DeleteUser(self, request: DeleteUserRequest) -> DeleteUserResponse:
		return self.stub.DeleteUser(request, metadata=self.headers)

	def UpdateUser(self, request: UpdateUserRequest) -> UpdateUserResponse:
		return self.stub.UpdateUser(request, metadata=self.headers)

	def GetMachineUserAuthToken(self, request: GetMachineUserAuthTokenRequest) -> GetMachineUserAuthTokenResponse:
		return self.stub.GetMachineUserAuthToken(request, metadata=self.headers)

	def RefreshMachineUserAuthToken(self, request: RefreshMachineUserAuthTokenRequest) -> RefreshMachineUserAuthTokenResponse:
		return self.stub.RefreshMachineUserAuthToken(request, metadata=self.headers)

	def GetUserExternalIds(self, request: GetUserExternalIdsRequest) -> GetUserExternalIdsResponse:
		return self.stub.GetUserExternalIds(request, metadata=self.headers)

	def MapUserToExternalId(self, request: MapUserToExternalIdRequest) -> MapUserToExternalIdResponse:
		return self.stub.MapUserToExternalId(request, metadata=self.headers)

	def DeleteExternalIdMapping(self, request: DeleteExternalIdMappingRequest) -> DeleteExternalIdMappingResponse:
		return self.stub.DeleteExternalIdMapping(request, metadata=self.headers)

from .gen.admin.v1.identities_pb2_grpc import GroupServiceStub
class GroupService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = GroupServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateGroup(self, request: CreateGroupRequest) -> CreateGroupResponse:
		return self.stub.CreateGroup(request, metadata=self.headers)

	def ListGroups(self, request: ListGroupsRequest) -> ListGroupsResponse:
		return self.stub.ListGroups(request, metadata=self.headers)

	def GetGroupById(self, request: GetGroupByIdRequest) -> GetGroupByIdResponse:
		return self.stub.GetGroupById(request, metadata=self.headers)

	def UpdateGroup(self, request: UpdateGroupRequest) -> UpdateGroupResponse:
		return self.stub.UpdateGroup(request, metadata=self.headers)

	def LinkUsersToGroup(self, request: LinkUsersToGroupRequest) -> LinkUsersToGroupResponse:
		return self.stub.LinkUsersToGroup(request, metadata=self.headers)

	def LinkUsersToGroupV2(self, request: LinkUsersToGroupV2Request) -> LinkUsersToGroupV2Response:
		return self.stub.LinkUsersToGroupV2(request, metadata=self.headers)

	def UnlinkUsersFromGroup(self, request: UnlinkUsersFromGroupRequest) -> UnlinkUsersFromGroupResponse:
		return self.stub.UnlinkUsersFromGroup(request, metadata=self.headers)

	def DeleteGroup(self, request: DeleteGroupRequest) -> DeleteGroupResponse:
		return self.stub.DeleteGroup(request, metadata=self.headers)




from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateNativeUserRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id", "native_user_secret", "use_as_default"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    USE_AS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    native_user_secret: str
    use_as_default: bool
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ..., use_as_default: bool = ...) -> None: ...

class CreateNativeUserResponse(_message.Message):
    __slots__ = ["native_user"]
    NATIVE_USER_FIELD_NUMBER: _ClassVar[int]
    native_user: NativeUser
    def __init__(self, native_user: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...

class GetNativeUsersRequest(_message.Message):
    __slots__ = ["data_store_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    def __init__(self, data_store_id: _Optional[str] = ...) -> None: ...

class GetNativeUsersResponse(_message.Message):
    __slots__ = ["native_users"]
    class NativeUsersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: NativeUser
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...
    NATIVE_USERS_FIELD_NUMBER: _ClassVar[int]
    native_users: _containers.MessageMap[str, NativeUser]
    def __init__(self, native_users: _Optional[_Mapping[str, NativeUser]] = ...) -> None: ...

class GetNativeUserRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class GetNativeUserResponse(_message.Message):
    __slots__ = ["native_user"]
    NATIVE_USER_FIELD_NUMBER: _ClassVar[int]
    native_user: NativeUser
    def __init__(self, native_user: _Optional[_Union[NativeUser, _Mapping]] = ...) -> None: ...

class NativeUser(_message.Message):
    __slots__ = ["datastore_id", "native_user_id", "native_user_secret", "use_as_default", "created_at", "users", "groups"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    USE_AS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    native_user_id: str
    native_user_secret: str
    use_as_default: bool
    created_at: int
    users: _containers.RepeatedScalarFieldContainer[str]
    groups: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, datastore_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ..., use_as_default: bool = ..., created_at: _Optional[int] = ..., users: _Optional[_Iterable[str]] = ..., groups: _Optional[_Iterable[str]] = ...) -> None: ...

class DeleteNativeUserRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class DeleteNativeUserResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateNativeUserSecretRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id", "native_user_secret"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_SECRET_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    native_user_secret: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., native_user_secret: _Optional[str] = ...) -> None: ...

class UpdateNativeUserSecretResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SetNativeUserAsDefaultRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...

class SetNativeUserAsDefaultResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ["data_store_id", "native_user_id", "identity_id", "formal_identity_type"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    identity_id: str
    formal_identity_type: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ...) -> None: ...

class CreateNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class GetNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ["data_store_id", "identity_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    identity_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...

class CreateNativeUserIdentityLinkV2Request(_message.Message):
    __slots__ = ["data_store_id", "native_user_id", "identity_id", "formal_identity_type"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    native_user_id: str
    identity_id: str
    formal_identity_type: str
    def __init__(self, data_store_id: _Optional[str] = ..., native_user_id: _Optional[str] = ..., identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ...) -> None: ...

class CreateNativeUserIdentityLinkV2Response(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class GetNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: NativeUserLink
    def __init__(self, link: _Optional[_Union[NativeUserLink, _Mapping]] = ...) -> None: ...

class DeleteNativeUserIdentityLinkRequest(_message.Message):
    __slots__ = ["data_store_id", "identity_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    identity_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., identity_id: _Optional[str] = ...) -> None: ...

class DeleteNativeUserIdentityLinkResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class NativeUserLink(_message.Message):
    __slots__ = ["data_store_id", "formal_identity_id", "formal_identity_type", "native_user_id"]
    DATA_STORE_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_IDENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    NATIVE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    data_store_id: str
    formal_identity_id: str
    formal_identity_type: str
    native_user_id: str
    def __init__(self, data_store_id: _Optional[str] = ..., formal_identity_id: _Optional[str] = ..., formal_identity_type: _Optional[str] = ..., native_user_id: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import identities_pb2 as admin_dot_v1_dot_identities__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListUsers = channel.unary_unary(
                '/admin.v1.UserService/ListUsers',
                request_serializer=admin_dot_v1_dot_identities__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.ListUsersResponse.FromString,
                )
        self.CreateUser = channel.unary_unary(
                '/admin.v1.UserService/CreateUser',
                request_serializer=admin_dot_v1_dot_identities__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.CreateUserResponse.FromString,
                )
        self.CreateUserV2 = channel.unary_unary(
                '/admin.v1.UserService/CreateUserV2',
                request_serializer=admin_dot_v1_dot_identities__pb2.CreateUserV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.CreateUserV2Response.FromString,
                )
        self.GetUserById = channel.unary_unary(
                '/admin.v1.UserService/GetUserById',
                request_serializer=admin_dot_v1_dot_identities__pb2.GetUserByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.GetUserByIdResponse.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/admin.v1.UserService/DeleteUser',
                request_serializer=admin_dot_v1_dot_identities__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.DeleteUserResponse.FromString,
                )
        self.UpdateUser = channel.unary_unary(
                '/admin.v1.UserService/UpdateUser',
                request_serializer=admin_dot_v1_dot_identities__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.UpdateUserResponse.FromString,
                )
        self.GetMachineUserAuthToken = channel.unary_unary(
                '/admin.v1.UserService/GetMachineUserAuthToken',
                request_serializer=admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenResponse.FromString,
                )
        self.RefreshMachineUserAuthToken = channel.unary_unary(
                '/admin.v1.UserService/RefreshMachineUserAuthToken',
                request_serializer=admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenResponse.FromString,
                )
        self.GetUserExternalIds = channel.unary_unary(
                '/admin.v1.UserService/GetUserExternalIds',
                request_serializer=admin_dot_v1_dot_identities__pb2.GetUserExternalIdsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.GetUserExternalIdsResponse.FromString,
                )
        self.MapUserToExternalId = channel.unary_unary(
                '/admin.v1.UserService/MapUserToExternalId',
                request_serializer=admin_dot_v1_dot_identities__pb2.MapUserToExternalIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.MapUserToExternalIdResponse.FromString,
                )
        self.DeleteExternalIdMapping = channel.unary_unary(
                '/admin.v1.UserService/DeleteExternalIdMapping',
                request_serializer=admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingResponse.FromString,
                )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMachineUserAuthToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshMachineUserAuthToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserExternalIds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MapUserToExternalId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteExternalIdMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.ListUsersRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.ListUsersResponse.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.CreateUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.CreateUserResponse.SerializeToString,
            ),
            'CreateUserV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserV2,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.CreateUserV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.CreateUserV2Response.SerializeToString,
            ),
            'GetUserById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserById,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.GetUserByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.GetUserByIdResponse.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.DeleteUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.DeleteUserResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.UpdateUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.UpdateUserResponse.SerializeToString,
            ),
            'GetMachineUserAuthToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMachineUserAuthToken,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenResponse.SerializeToString,
            ),
            'RefreshMachineUserAuthToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshMachineUserAuthToken,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenResponse.SerializeToString,
            ),
            'GetUserExternalIds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserExternalIds,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.GetUserExternalIdsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.GetUserExternalIdsResponse.SerializeToString,
            ),
            'MapUserToExternalId': grpc.unary_unary_rpc_method_handler(
                    servicer.MapUserToExternalId,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.MapUserToExternalIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.MapUserToExternalIdResponse.SerializeToString,
            ),
            'DeleteExternalIdMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteExternalIdMapping,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/ListUsers',
            admin_dot_v1_dot_identities__pb2.ListUsersRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/CreateUser',
            admin_dot_v1_dot_identities__pb2.CreateUserRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.CreateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/CreateUserV2',
            admin_dot_v1_dot_identities__pb2.CreateUserV2Request.SerializeToString,
            admin_dot_v1_dot_identities__pb2.CreateUserV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/GetUserById',
            admin_dot_v1_dot_identities__pb2.GetUserByIdRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.GetUserByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/DeleteUser',
            admin_dot_v1_dot_identities__pb2.DeleteUserRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.DeleteUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/UpdateUser',
            admin_dot_v1_dot_identities__pb2.UpdateUserRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.UpdateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMachineUserAuthToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/GetMachineUserAuthToken',
            admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.GetMachineUserAuthTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshMachineUserAuthToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/RefreshMachineUserAuthToken',
            admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.RefreshMachineUserAuthTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserExternalIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/GetUserExternalIds',
            admin_dot_v1_dot_identities__pb2.GetUserExternalIdsRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.GetUserExternalIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MapUserToExternalId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/MapUserToExternalId',
            admin_dot_v1_dot_identities__pb2.MapUserToExternalIdRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.MapUserToExternalIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteExternalIdMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.UserService/DeleteExternalIdMapping',
            admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.DeleteExternalIdMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class GroupServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateGroup = channel.unary_unary(
                '/admin.v1.GroupService/CreateGroup',
                request_serializer=admin_dot_v1_dot_identities__pb2.CreateGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.CreateGroupResponse.FromString,
                )
        self.ListGroups = channel.unary_unary(
                '/admin.v1.GroupService/ListGroups',
                request_serializer=admin_dot_v1_dot_identities__pb2.ListGroupsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.ListGroupsResponse.FromString,
                )
        self.GetGroupById = channel.unary_unary(
                '/admin.v1.GroupService/GetGroupById',
                request_serializer=admin_dot_v1_dot_identities__pb2.GetGroupByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.GetGroupByIdResponse.FromString,
                )
        self.UpdateGroup = channel.unary_unary(
                '/admin.v1.GroupService/UpdateGroup',
                request_serializer=admin_dot_v1_dot_identities__pb2.UpdateGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.UpdateGroupResponse.FromString,
                )
        self.LinkUsersToGroup = channel.unary_unary(
                '/admin.v1.GroupService/LinkUsersToGroup',
                request_serializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupResponse.FromString,
                )
        self.LinkUsersToGroupV2 = channel.unary_unary(
                '/admin.v1.GroupService/LinkUsersToGroupV2',
                request_serializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Response.FromString,
                )
        self.UnlinkUsersFromGroup = channel.unary_unary(
                '/admin.v1.GroupService/UnlinkUsersFromGroup',
                request_serializer=admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupResponse.FromString,
                )
        self.DeleteGroup = channel.unary_unary(
                '/admin.v1.GroupService/DeleteGroup',
                request_serializer=admin_dot_v1_dot_identities__pb2.DeleteGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_identities__pb2.DeleteGroupResponse.FromString,
                )


class GroupServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkUsersToGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkUsersToGroupV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnlinkUsersFromGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroup,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.CreateGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.CreateGroupResponse.SerializeToString,
            ),
            'ListGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGroups,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.ListGroupsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.ListGroupsResponse.SerializeToString,
            ),
            'GetGroupById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupById,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.GetGroupByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.GetGroupByIdResponse.SerializeToString,
            ),
            'UpdateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateGroup,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.UpdateGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.UpdateGroupResponse.SerializeToString,
            ),
            'LinkUsersToGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkUsersToGroup,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupResponse.SerializeToString,
            ),
            'LinkUsersToGroupV2': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkUsersToGroupV2,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Response.SerializeToString,
            ),
            'UnlinkUsersFromGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UnlinkUsersFromGroup,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupResponse.SerializeToString,
            ),
            'DeleteGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteGroup,
                    request_deserializer=admin_dot_v1_dot_identities__pb2.DeleteGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_identities__pb2.DeleteGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.GroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GroupService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/CreateGroup',
            admin_dot_v1_dot_identities__pb2.CreateGroupRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.CreateGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/ListGroups',
            admin_dot_v1_dot_identities__pb2.ListGroupsRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.ListGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/GetGroupById',
            admin_dot_v1_dot_identities__pb2.GetGroupByIdRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.GetGroupByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/UpdateGroup',
            admin_dot_v1_dot_identities__pb2.UpdateGroupRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.UpdateGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkUsersToGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/LinkUsersToGroup',
            admin_dot_v1_dot_identities__pb2.LinkUsersToGroupRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.LinkUsersToGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkUsersToGroupV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/LinkUsersToGroupV2',
            admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Request.SerializeToString,
            admin_dot_v1_dot_identities__pb2.LinkUsersToGroupV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnlinkUsersFromGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/UnlinkUsersFromGroup',
            admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.UnlinkUsersFromGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GroupService/DeleteGroup',
            admin_dot_v1_dot_identities__pb2.DeleteGroupRequest.SerializeToString,
            admin_dot_v1_dot_identities__pb2.DeleteGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc


from .gen.admin.v1.policies_pb2 import (
	PolicyRuleType,
	PolicyType,
	CreatePolicySuggestionRequest,
	CreatePolicySuggestionResponse,
	DeletePolicyRequest,
	DeletePolicyResponse,
	EvaluatePolicyValidityRequest,
	EvaluatePolicyValidityResponse,
	DryRunPoliciesRequest,
	ColumnPolicy,
	AWSAccount,
	AWSEC2,
	AWSECS,
	AWS,
	DryRunPoliciesResponse,
	CreatePolicyRequest,
	CreatePolicyV2Request,
	CreatePolicyResponse,
	CreatePolicyV2Response,
	UpdatePolicyRequest,
	UpdatePolicyV2Request,
	UpdatePolicyResponse,
	UpdatePolicyV2Response,
	GetPolicyRequest,
	GetPolicyV2Request,
	GetPolicyResponse,
	GetPolicyV2Response,
	GetPoliciesRequest,
	GetPoliciesResponse,
)

from .gen.admin.v1.policies_pb2_grpc import PolicyServiceStub
class PolicyService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = PolicyServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetPolicies(self, request: GetPoliciesRequest) -> GetPoliciesResponse:
		return self.stub.GetPolicies(request, metadata=self.headers)

	def GetPolicy(self, request: GetPolicyRequest) -> GetPolicyResponse:
		return self.stub.GetPolicy(request, metadata=self.headers)

	def GetPolicyV2(self, request: GetPolicyV2Request) -> GetPolicyV2Response:
		return self.stub.GetPolicyV2(request, metadata=self.headers)

	def CreatePolicy(self, request: CreatePolicyRequest) -> CreatePolicyResponse:
		return self.stub.CreatePolicy(request, metadata=self.headers)

	def CreatePolicyV2(self, request: CreatePolicyV2Request) -> CreatePolicyV2Response:
		return self.stub.CreatePolicyV2(request, metadata=self.headers)

	def UpdatePolicy(self, request: UpdatePolicyRequest) -> UpdatePolicyResponse:
		return self.stub.UpdatePolicy(request, metadata=self.headers)

	def UpdatePolicyV2(self, request: UpdatePolicyV2Request) -> UpdatePolicyV2Response:
		return self.stub.UpdatePolicyV2(request, metadata=self.headers)

	def DeletePolicy(self, request: DeletePolicyRequest) -> DeletePolicyResponse:
		return self.stub.DeletePolicy(request, metadata=self.headers)

	def DryRunPolicies(self, request: DryRunPoliciesRequest) -> DryRunPoliciesResponse:
		return self.stub.DryRunPolicies(request, metadata=self.headers)

	def EvaluatePolicyValidity(self, request: EvaluatePolicyValidityRequest) -> EvaluatePolicyValidityResponse:
		return self.stub.EvaluatePolicyValidity(request, metadata=self.headers)

	def CreatePolicySuggestion(self, request: CreatePolicySuggestionRequest) -> CreatePolicySuggestionResponse:
		return self.stub.CreatePolicySuggestion(request, metadata=self.headers)




import grpc


from .gen.admin.v1.work_os_pb2 import (
	GetDirectoryRequest,
	GetDirectoryResponse,
	Directory,
	GetGroupsByDirectoryIdRequest,
	GetGroupsByDirectoryIdResponse,
	GetUsersByDirectoryIdRequest,
	GetUsersByDirectoryIdResponse,
	GetWorkOsGroupByIdRequest,
	GetWorkOsGroupByIdResponse,
	DirectorySyncGroup,
	UserEmail,
	UserGroup,
	WorkUser,
	Users,
	Group,
	GroupPair,
	GetDirectoryGroupsRequest,
	GetDirectoryGroupsResponse,
	UpdateDirectoryGroupSyncRequest,
	UpdateDirectoryGroupSyncResponse,
	GetDSyncPortalRequest,
	GetDSyncPortalResponse,
)

from .gen.admin.v1.work_os_pb2_grpc import DSyncServiceStub
class DSyncService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = DSyncServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetDirectory(self, request: GetDirectoryRequest) -> GetDirectoryResponse:
		return self.stub.GetDirectory(request, metadata=self.headers)

	def GetGroupsByDirectoryId(self, request: GetGroupsByDirectoryIdRequest) -> GetGroupsByDirectoryIdResponse:
		return self.stub.GetGroupsByDirectoryId(request, metadata=self.headers)

	def GetUsersByDirectoryId(self, request: GetUsersByDirectoryIdRequest) -> GetUsersByDirectoryIdResponse:
		return self.stub.GetUsersByDirectoryId(request, metadata=self.headers)

	def GetWorkOsGroupById(self, request: GetWorkOsGroupByIdRequest) -> GetWorkOsGroupByIdResponse:
		return self.stub.GetWorkOsGroupById(request, metadata=self.headers)

	def GetDirectoryGroups(self, request: GetDirectoryGroupsRequest) -> GetDirectoryGroupsResponse:
		return self.stub.GetDirectoryGroups(request, metadata=self.headers)

	def UpdateDirectoryGroupSync(self, request: UpdateDirectoryGroupSyncRequest) -> UpdateDirectoryGroupSyncResponse:
		return self.stub.UpdateDirectoryGroupSync(request, metadata=self.headers)

	def GetDSyncPortal(self, request: GetDSyncPortalRequest) -> GetDSyncPortalResponse:
		return self.stub.GetDSyncPortal(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_cloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import flat_dataplane_pb2 as admin_dot_v1_dot_types_dot_v1_dot_flat__dataplane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_cloud.proto\x12\x08\x61\x64min.v1\x1a&admin/v1/types/v1/flat_dataplane.proto\"\xbc\x01\n\x16\x43reateDataplaneRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\x12(\n\x10\x63loud_account_id\x18\x03 \x01(\tR\x0e\x63loudAccountId\x12+\n\x11\x61vailability_zone\x18\x04 \x01(\x05R\x10\x61vailabilityZone\x12\x1f\n\x0bvpc_peering\x18\x05 \x01(\x08R\nvpcPeering\"Y\n\x17\x43reateDataplaneResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\")\n\x17GetDataplaneByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x18GetDataplaneByIdResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\"(\n\x16\x44\x65leteDataplaneRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteDataplaneResponse\"\xe0\x01\n\x1c\x43reateDataplaneRoutesRequest\x12!\n\x0c\x64\x61taplane_id\x18\x01 \x01(\tR\x0b\x64\x61taplaneId\x12\x34\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\tR\x14\x64\x65stinationCidrBlock\x12,\n\x12transit_gateway_id\x18\x03 \x01(\tR\x10transitGatewayId\x12\x39\n\x19vpc_peering_connection_id\x18\x04 \x01(\tR\x16vpcPeeringConnectionId\"|\n\x1d\x43reateDataplaneRoutesResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\"/\n\x1dGetDataplaneRoutesByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"}\n\x1eGetDataplaneRoutesByIdResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\".\n\x1c\x44\x65leteDataplaneRoutesRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"9\n\x1d\x44\x65leteDataplaneRoutesResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x83\x01\n!CreateAwsConnectionSessionRequest\x12,\n\x12\x63loud_account_name\x18\x01 \x01(\tR\x10\x63loudAccountName\x12\x30\n\x14\x63loud_account_region\x18\x02 \x01(\tR\x12\x63loudAccountRegion\"v\n\"CreateAwsConnectionSessionResponse\x12P\n\x11\x63loud_integration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x10\x63loudIntegration\"3\n!DeleteAwsConnectionSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"8\n&GetIntegrationsCloudAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"p\n\'GetIntegrationsCloudAccountByIdResponse\x12\x45\n\x0bintegration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0bintegration\"%\n#GetIntegrationsCloudAccountsRequest\"o\n$GetIntegrationsCloudAccountsResponse\x12G\n\x0cintegrations\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0cintegrations\"B\n!CreateGcpConnectionSessionRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"$\n\"CreateGcpConnectionSessionResponse\"$\n\"DeleteAwsConnectionSessionResponse\"U\n)GetDataplaneStacksByCloudAccountIdRequest\x12(\n\x10\x63loud_account_id\x18\x01 \x01(\tR\x0e\x63loudAccountId\"n\n*GetDataplaneStacksByCloudAccountIdResponse\x12@\n\ndataplanes\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\ndataplanes2\xdf\n\n\x0c\x43loudService\x12V\n\x0f\x43reateDataplane\x12 .admin.v1.CreateDataplaneRequest\x1a!.admin.v1.CreateDataplaneResponse\x12Y\n\x10GetDataplaneById\x12!.admin.v1.GetDataplaneByIdRequest\x1a\".admin.v1.GetDataplaneByIdResponse\x12V\n\x0f\x44\x65leteDataplane\x12 .admin.v1.DeleteDataplaneRequest\x1a!.admin.v1.DeleteDataplaneResponse\x12h\n\x15\x43reateDataplaneRoutes\x12&.admin.v1.CreateDataplaneRoutesRequest\x1a\'.admin.v1.CreateDataplaneRoutesResponse\x12k\n\x16GetDataplaneRoutesById\x12\'.admin.v1.GetDataplaneRoutesByIdRequest\x1a(.admin.v1.GetDataplaneRoutesByIdResponse\x12h\n\x15\x44\x65leteDataplaneRoutes\x12&.admin.v1.DeleteDataplaneRoutesRequest\x1a\'.admin.v1.DeleteDataplaneRoutesResponse\x12\x8f\x01\n\"GetDataplaneStacksByCloudAccountId\x12\x33.admin.v1.GetDataplaneStacksByCloudAccountIdRequest\x1a\x34.admin.v1.GetDataplaneStacksByCloudAccountIdResponse\x12w\n\x1a\x43reateAwsConnectionSession\x12+.admin.v1.CreateAwsConnectionSessionRequest\x1a,.admin.v1.CreateAwsConnectionSessionResponse\x12w\n\x1a\x44\x65leteAwsConnectionSession\x12+.admin.v1.DeleteAwsConnectionSessionRequest\x1a,.admin.v1.DeleteAwsConnectionSessionResponse\x12\x86\x01\n\x1fGetIntegrationsCloudAccountById\x12\x30.admin.v1.GetIntegrationsCloudAccountByIdRequest\x1a\x31.admin.v1.GetIntegrationsCloudAccountByIdResponse\x12}\n\x1cGetIntegrationsCloudAccounts\x12-.admin.v1.GetIntegrationsCloudAccountsRequest\x1a..admin.v1.GetIntegrationsCloudAccountsResponse\x12w\n\x1a\x43reateGcpConnectionSession\x12+.admin.v1.CreateGcpConnectionSessionRequest\x1a,.admin.v1.CreateGcpConnectionSessionResponseB\xb0\x01\n\x0c\x63om.admin.v1B\x15IntegrationCloudProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_cloud_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationCloudProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEDATAPLANEREQUEST']._serialized_start=87
  _globals['_CREATEDATAPLANEREQUEST']._serialized_end=275
  _globals['_CREATEDATAPLANERESPONSE']._serialized_start=277
  _globals['_CREATEDATAPLANERESPONSE']._serialized_end=366
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_start=368
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_end=409
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_start=411
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_end=501
  _globals['_DELETEDATAPLANEREQUEST']._serialized_start=503
  _globals['_DELETEDATAPLANEREQUEST']._serialized_end=543
  _globals['_DELETEDATAPLANERESPONSE']._serialized_start=545
  _globals['_DELETEDATAPLANERESPONSE']._serialized_end=570
  _globals['_CREATEDATAPLANEROUTESREQUEST']._serialized_start=573
  _globals['_CREATEDATAPLANEROUTESREQUEST']._serialized_end=797
  _globals['_CREATEDATAPLANEROUTESRESPONSE']._serialized_start=799
  _globals['_CREATEDATAPLANEROUTESRESPONSE']._serialized_end=923
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_start=925
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_end=972
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_start=974
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_end=1099
  _globals['_DELETEDATAPLANEROUTESREQUEST']._serialized_start=1101
  _globals['_DELETEDATAPLANEROUTESREQUEST']._serialized_end=1147
  _globals['_DELETEDATAPLANEROUTESRESPONSE']._serialized_start=1149
  _globals['_DELETEDATAPLANEROUTESRESPONSE']._serialized_end=1206
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_start=1209
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_end=1340
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1342
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1460
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_start=1462
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_end=1513
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_start=1515
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_end=1571
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_start=1573
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_end=1685
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_start=1687
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_end=1724
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_start=1726
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_end=1837
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_start=1839
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_end=1905
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_start=1907
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_end=1943
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1945
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1981
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_start=1983
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_end=2068
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_start=2070
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_end=2180
  _globals['_CLOUDSERVICE']._serialized_start=2183
  _globals['_CLOUDSERVICE']._serialized_end=3558
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSlackIntegrationRequest(_message.Message):
    __slots__ = ["code", "redirect_uri"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    code: str
    redirect_uri: str
    def __init__(self, code: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class CreateSlackIntegrationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetSlackIntegrationRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetSlackIntegrationResponse(_message.Message):
    __slots__ = ["team_id", "team_name", "bot_user_id", "bot_access_token", "authed_user_id", "channel_id"]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    TEAM_NAME_FIELD_NUMBER: _ClassVar[int]
    BOT_USER_ID_FIELD_NUMBER: _ClassVar[int]
    BOT_ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    AUTHED_USER_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    team_id: str
    team_name: str
    bot_user_id: str
    bot_access_token: str
    authed_user_id: str
    channel_id: str
    def __init__(self, team_id: _Optional[str] = ..., team_name: _Optional[str] = ..., bot_user_id: _Optional[str] = ..., bot_access_token: _Optional[str] = ..., authed_user_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_app_pb2 as admin_dot_v1_dot_integration__app__pb2


class AppServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RefreshIntegrationApps = channel.unary_unary(
                '/admin.v1.AppService/RefreshIntegrationApps',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.FromString,
                )
        self.GetIntegrationApps = channel.unary_unary(
                '/admin.v1.AppService/GetIntegrationApps',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.FromString,
                )
        self.GetIntegrationById = channel.unary_unary(
                '/admin.v1.AppService/GetIntegrationById',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.FromString,
                )
        self.CreateIntegrationApp = channel.unary_unary(
                '/admin.v1.AppService/CreateIntegrationApp',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.FromString,
                )
        self.DeleteIntegrationApp = channel.unary_unary(
                '/admin.v1.AppService/DeleteIntegrationApp',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.FromString,
                )


class AppServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RefreshIntegrationApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIntegrationApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AppServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RefreshIntegrationApps': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshIntegrationApps,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.SerializeToString,
            ),
            'GetIntegrationApps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationApps,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.SerializeToString,
            ),
            'GetIntegrationById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationById,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.SerializeToString,
            ),
            'CreateIntegrationApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationApp,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.SerializeToString,
            ),
            'DeleteIntegrationApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationApp,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.AppService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AppService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RefreshIntegrationApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/RefreshIntegrationApps',
            admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/GetIntegrationApps',
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/GetIntegrationById',
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateIntegrationApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/CreateIntegrationApp',
            admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegrationApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/DeleteIntegrationApp',
            admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc


from .gen.admin.v1.native_user_pb2 import (
	CreateNativeUserRequest,
	CreateNativeUserResponse,
	GetNativeUsersRequest,
	GetNativeUsersResponse,
	GetNativeUserRequest,
	GetNativeUserResponse,
	NativeUser,
	DeleteNativeUserRequest,
	DeleteNativeUserResponse,
	UpdateNativeUserSecretRequest,
	UpdateNativeUserSecretResponse,
	SetNativeUserAsDefaultRequest,
	SetNativeUserAsDefaultResponse,
	CreateNativeUserIdentityLinkRequest,
	CreateNativeUserIdentityLinkResponse,
	GetNativeUserIdentityLinkRequest,
	CreateNativeUserIdentityLinkV2Request,
	CreateNativeUserIdentityLinkV2Response,
	GetNativeUserIdentityLinkResponse,
	DeleteNativeUserIdentityLinkRequest,
	DeleteNativeUserIdentityLinkResponse,
	NativeUserLink,
)

from .gen.admin.v1.native_user_pb2_grpc import NativeUserServiceStub
class NativeUserService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = NativeUserServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateNativeUser(self, request: CreateNativeUserRequest) -> CreateNativeUserResponse:
		return self.stub.CreateNativeUser(request, metadata=self.headers)

	def GetNativeUser(self, request: GetNativeUserRequest) -> GetNativeUserResponse:
		return self.stub.GetNativeUser(request, metadata=self.headers)

	def GetNativeUsers(self, request: GetNativeUsersRequest) -> GetNativeUsersResponse:
		return self.stub.GetNativeUsers(request, metadata=self.headers)

	def DeleteNativeUser(self, request: DeleteNativeUserRequest) -> DeleteNativeUserResponse:
		return self.stub.DeleteNativeUser(request, metadata=self.headers)

	def UpdateNativeUserSecret(self, request: UpdateNativeUserSecretRequest) -> UpdateNativeUserSecretResponse:
		return self.stub.UpdateNativeUserSecret(request, metadata=self.headers)

	def SetNativeUserAsDefault(self, request: SetNativeUserAsDefaultRequest) -> SetNativeUserAsDefaultResponse:
		return self.stub.SetNativeUserAsDefault(request, metadata=self.headers)

	def CreateNativeUserIdentityLink(self, request: CreateNativeUserIdentityLinkRequest) -> CreateNativeUserIdentityLinkResponse:
		return self.stub.CreateNativeUserIdentityLink(request, metadata=self.headers)

	def CreateNativeUserIdentityLinkV2(self, request: CreateNativeUserIdentityLinkV2Request) -> CreateNativeUserIdentityLinkV2Response:
		return self.stub.CreateNativeUserIdentityLinkV2(request, metadata=self.headers)

	def GetNativeUserIdentityLink(self, request: GetNativeUserIdentityLinkRequest) -> GetNativeUserIdentityLinkResponse:
		return self.stub.GetNativeUserIdentityLink(request, metadata=self.headers)

	def DeleteNativeUserIdentityLink(self, request: DeleteNativeUserIdentityLinkRequest) -> DeleteNativeUserIdentityLinkResponse:
		return self.stub.DeleteNativeUserIdentityLink(request, metadata=self.headers)

